#!/usr/bin/env python

import os
import datetime
#from datetime import date
import re
source_directory = os.path.dirname(os.path.abspath(__file__))

package_name = "vlconf"

# print(source_directory)

def get_current_version():
    """ Get the current version """
    line_found=False
    with open(f"{source_directory}/{package_name}/__init__.py") as vf:
        while not line_found:
            one_line = vf.readline()
            if "__version__" in one_line:
                line_found=True
    
    current_version = re.search(r'\d+.\d+.\d+[.\d+]*', one_line).group(0)
    current_major_version = re.search(r'\d+.\d+.\d+', one_line).group(0)
    version_segments = current_version.split(".")

    print(f"Current version {current_version}")
    print(f"Current major version {current_major_version}")
    
    if len(version_segments)==3:
        current_minor_version=None
    elif len(version_segments)==4:
        current_minor_version=version_segments[-1]
    else:
        raise ValueError("Version not read properly")

    print(f"Current minor version {current_minor_version}")

    return current_version, current_major_version, current_minor_version


def write_git_version():
    """Write the latest version number based on the last commit date
    to the public folder and to __init__.py file"""

    # print(package_directory)
    # Open the file
    # Get the version
    # vers = os.popen(f'git -C {source_directory} log -1 --date=short | grep Date').read()[8:-1]
    # new_major_version = str(date.today())
    new_major_version = str(datetime.datetime.now(datetime.UTC).date())
    new_major_version = new_major_version.replace("-", ".")

    current_version, current_major_version, current_minor_version = get_current_version()
    
    if new_major_version==current_major_version:
        if current_minor_version is None:
            new_minor_version=1
        else:
            new_minor_version= int(current_minor_version)+1
        
        new_version = f"{new_major_version}.{new_minor_version}"

    else:
        new_minor_version=None
        new_version = new_major_version

    # Write to public/version
    with open(source_directory + "/public/version", "w") as vers_file:
        vers_file.writelines([new_version])

    # write to __init__.py
    ee = os.popen(
        f"sed -i '/__version__/c\\__version__ = \"{new_version}\"' {source_directory}/{package_name}/__init__.py"
    )
    # with open(package_directory+'/{package_name}/__init__.py', 'r') as init_file:
    # with open(package_directory + "/../public/date.txt", "r") as vers_file:
    # vers = vers_file.read()[:10]

    ee = os.popen(
        f"sed -i '/version/c\\ \tversion=\"{new_version}\",' {source_directory}/setup.py"
    )
    print("Version", new_version)

    # Generate badge
    badge = f"""<svg width="140" height="20" xmlns="http://www.w3.org/2000/svg">
                <rect width="80" height="20" rx="0" ry="5" fill="grey" x="0" y="0" />
                <rect width="60" height="20" fill="blue" x="80" y="0" />
                <text x="6" y="13" fill="white" font-size="11">pypi package</text>
                <text x="83" y="14" fill="white" font-size="11">{new_version}</text>
                </svg>
            """

    with open("docs/vers_badge.svg", "w") as svgf:
        svgf.write(badge)

    return new_version


write_git_version()



# init

__version__ = "2025.09.11"

#####################
# Message verbosity
#####################

print_verbosity=1
log_verbosity = 1


##################################
# matplotlib presets
##################################


def conf_matplotlib(
    reset=False,
    legend_marker_scale=2,
    grid=True,
    grid_alpha=0.3,
    fig_autolayout=True,
    labelsize=16,
    labelpad=14,
    font_size=12,
    fig_size=(8, 6),
):
    """Configure matplotlib plot style.

    Parameters
    ----------
    reset : bool
            Whether or not to reset the plot
            layout before configuring.
    fig_size : tuple of int
               The size of the figure.
    fig_autolayout : bool
                     To turn on the figure autolayout
                     or not.
    grid : bool
           Turn grid on or off.
    grid_alpha : float
                 The transparency level of the
                 grid.
    labelsize : int
                The axes label size.
    labelpad : int
               The axes label pad.
    legend_marker_scale : int
                          The legend marker scale.
    """

    import matplotlib.pyplot as plt

    if reset:
        reset_matplotlib()

    plt.rcParams.update({"font.size": font_size})
    plt.rcParams.update({"figure.figsize": fig_size})
    plt.rcParams.update({"axes.grid": grid})
    plt.rcParams.update({"axes.labelpad": labelpad})
    plt.rcParams.update({"axes.labelsize": labelsize})
    plt.rcParams.update({"figure.autolayout": fig_autolayout})
    plt.rcParams.update({"grid.alpha": grid_alpha})
    plt.rcParams.update({"legend.markerscale": legend_marker_scale})


def reset_matplotlib():
    import matplotlib

    matplotlib.rcParams.update(matplotlib.rcParamsDefault)



import os

import vlconf
from importlib import reload

cf_loc = vlconf.__file__


def overwrite_verbosity_level(verb_type, verb_val):
    """Change the verbosity value for the given verbosity type verb_val"""
    ee = os.popen(
        f"sed -i '/{verb_type}_verbosity/c\\{verb_type}_verbosity"
        f"={verb_val}' {cf_loc}"
    )

    print(f"{verb_type} verbosity has been set to {verb_val} at {cf_loc}")


class levels:
    def __init__(self, log_verbosity=1, print_verbosity=1):

        self._log_verbosity = log_verbosity
        self._print_verbosity = print_verbosity

        if not os.path.exists(f"{cf_loc}"):
            with open(f"{cf_loc}", "w") as verbosity_file:
                verbosity_file.write("# Configuration file\n# Verbosity\n")
                verbosity_file.write("log_verbosity = 1\n")
                verbosity_file.write("print_verbosity = 1\n")

    def set_log_verbosity(self, log_verbosity):
        self._log_verbosity = log_verbosity
        overwrite_verbosity_level("log", log_verbosity)

    def set_print_verbosity(self, print_verbosity):
        self._print_verbosity = print_verbosity
        overwrite_verbosity_level("print", print_verbosity)

    @property
    def log_verbosity(self):
        reload(vlconf)
        return vlconf.log_verbosity
        # return self._log_verbosity

    @property
    def print_verbosity(self):
        reload(vlconf)
        return vlconf.print_verbosity
        # return self._print_verbosity

    def get_file_location(self):
        return vlconf.__file__



# Setup file

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


def get_requirements():
    """Get the requirement libraries"""
    with open("requirements.txt") as freq:
        rlines = freq.readlines()
        # print(rlines)
        mreq = rlines[2:]

    with open("optional-requirements.txt") as foreq:
        rlines = foreq.readlines()

        oreq = rlines[2:]

    return mreq, oreq



setuptools.setup(
    name="vlconf",
 	version="2025.09.11",
    author="Vaishak Prasad",
    author_email="vaishakprasad@gmail.com",
    description="Global python configuration and verbosity levels",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/vaishakp/config",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3",
)
